@@ -26,7 +26,7 @@ library(groupdata2)
 # Attaching other packages used in this vignette
 library(dplyr)
 library(tidyr)
-library(ggplot2)
+require(ggplot2, quietly = TRUE)  # Attach if installed
 library(knitr)
 
 # We will also be using plyr a few times, but we don't attach this 
@@ -35,9 +35,11 @@ library(knitr)
 
 
 ## -----------------------------------------------------------------------------
-df <- data.frame("x"=c(1:12), 
-                "species" = factor(rep(c('cat','pig', 'human'), 4)), 
-                "age" = sample(c(1:100), 12))
+df <- data.frame(
+  "x" = c(1:12), 
+  "species" = factor(rep(c('cat', 'pig', 'human'), 4)), 
+  "age" = sample(c(1:100), 12)
+)
 
 
 ## -----------------------------------------------------------------------------
@@ -58,9 +60,11 @@ df %>%
 
 
 ## -----------------------------------------------------------------------------
-df <- data.frame("x"=c(1:12), 
-                "species" = factor(rep(c('cat','pig', 'human'), 4)), 
-                "age" = sample(c(1:100), 12))
+df <- data.frame(
+  "x" = c(1:12),  
+  "species" = factor(rep(c('cat', 'pig', 'human'), 4)), 
+  "age" = sample(c(1:100), 12)
+)
 
 
 ## -----------------------------------------------------------------------------
@@ -81,9 +85,11 @@ df %>% kable(align = 'c')
 
 
 ## -----------------------------------------------------------------------------
-df <- data.frame("x"=c(1:12), 
-                "species" = factor(rep(c('cat','pig', 'human'), 4)), 
-                "age" = sample(c(1:100), 12))
+df <- data.frame(
+  "x" = c(1:12),  
+  "species" = factor(rep(c('cat', 'pig', 'human'), 4)), 
+  "age" = sample(c(1:100), 12)
+)
 
 
 ## -----------------------------------------------------------------------------
@@ -101,9 +107,11 @@ df_means %>% kable(align = 'c')
 
 
 ## -----------------------------------------------------------------------------
-df <- data.frame("x"=c(1:12), 
-                "species" = factor(rep(c('cat','pig', 'human'), 4)), 
-                "age" = sample(c(1:100), 12))
+df <- data.frame(
+  "x" = c(1:12),  
+  "species" = factor(rep(c('cat', 'pig', 'human'), 4)), 
+  "age" = sample(c(1:100), 12)
+)
 
 
 
@@ -115,9 +123,11 @@ df_grouped %>% kable(align = 'c')
 
 
 ## -----------------------------------------------------------------------------
-df <- data.frame("x"=c(1:12), 
-                "species" = factor(rep(c('cat','pig', 'human'), 4)), 
-                "age" = sample(c(1:100), 12))
+df <- data.frame(
+  "x" = c(1:12),  
+  "species" = factor(rep(c('cat', 'pig', 'human'), 4)), 
+  "age" = sample(c(1:100), 12)
+)
 
 
 
@@ -128,16 +138,17 @@ df_list %>% kable(align = 'c')
 
 
 ## -----------------------------------------------------------------------------
-
-v = c(1:6)
+v <- c(1:6)
 
 splt(v, 3, method = 'n_dist')
 
 
 ## -----------------------------------------------------------------------------
-df <- data.frame("x"=c(1:12), 
-                "species" = factor(rep(c('cat','pig', 'human'), 4)), 
-                "age" = sample(c(1:100), 12))
+df <- data.frame(
+  "x" = c(1:12),  
+  "species" = factor(rep(c('cat', 'pig', 'human'), 4)), 
+  "age" = sample(c(1:100), 12)
+)
 
 
 ## -----------------------------------------------------------------------------
@@ -147,10 +158,12 @@ df_list %>% kable(align = 'c')
 
 
 ## -----------------------------------------------------------------------------
-df <- data.frame("participant" = factor(rep(c('1','2', '3', '4', '5', '6'), 3)),
-                "age" = rep(sample(c(1:100), 6), 3),
-                "diagnosis" = factor(rep(c('a', 'b', 'a', 'a', 'b', 'b'), 3)),
-                "score" = sample(c(1:100), 3*6))
+df <- data.frame(
+  "participant" = factor(rep(c('1', '2', '3', '4', '5', '6'), 3)), 
+  "age" = rep(sample(c(1:100), 6), 3), 
+  "diagnosis" = factor(rep(c('a', 'b', 'a', 'a', 'b', 'b'), 3)), 
+  "score" = sample(c(1:100), 3 * 6)
+)
 
 df <- df %>% 
   arrange(participant)
@@ -227,10 +240,12 @@ df_folded %>%
 
 
 ## -----------------------------------------------------------------------------
-df <- data.frame("participant" = factor(rep(c('1','2', '3', '4', '5', '6'), 3)),
-                "age" = rep(sample(c(1:100), 6), 3),
-                "diagnosis" = factor(rep(c('a', 'b', 'a', 'a', 'b', 'b'), 3)),
-                "score" = sample(c(1:100), 3*6))
+df <- data.frame(
+  "participant" = factor(rep(c('1', '2', '3', '4', '5', '6'), 3)), 
+  "age" = rep(sample(c(1:100), 6), 3), 
+  "diagnosis" = factor(rep(c('a', 'b', 'a', 'a', 'b', 'b'), 3)), 
+  "score" = sample(c(1:100), 3 * 6)
+)
 
 df <- df %>% arrange(participant)
 
@@ -292,8 +307,13 @@ df_partitioned %>%
 
 
 ## -----------------------------------------------------------------------------
-df_partitioned <- partition(df, 0.5, cat_col = 'diagnosis', id_col = 'participant', 
-                            list_out = FALSE)
+df_partitioned <- partition(
+  data = df, 
+  p = 0.5, 
+  cat_col = 'diagnosis', 
+  id_col = 'participant', 
+  list_out = FALSE
+)
 
 # Order by folds
 df_partitioned <- df_partitioned %>% 
@@ -312,10 +332,12 @@ df_partitioned %>%
 set.seed(2)
 
 ## -----------------------------------------------------------------------------
-df <- data.frame("participant" = factor(rep(c('1','2', '3', '4', '5', '6'), 3)),
-                "age" = rep(sample(c(1:100), 6), 3),
-                "diagnosis" = factor(rep(c('a', 'b', 'a', 'a', 'b', 'b'), 3)),
-                "score" = sample(c(1:100), 3*6))
+df <- data.frame(
+  "participant" = factor(rep(c('1', '2', '3', '4', '5', '6'), 3)), 
+  "age" = rep(sample(c(1:100), 6), 3), 
+  "diagnosis" = factor(rep(c('a', 'b', 'a', 'a', 'b', 'b'), 3)), 
+  "score" = sample(c(1:100), 3 * 6)
+)
 
 df <- df %>% 
   arrange(participant)
@@ -438,9 +460,11 @@ df_balanced %>%
 
 
 ## -----------------------------------------------------------------------------
-df <- data.frame("x"=c(1:12), 
-                "species" = factor(rep(c('cat','pig', 'human'), 4)), 
-                "age" = sample(c(1:100), 12))
+df <- data.frame(
+  "x" = c(1:12), 
+  "species" = factor(rep(c('cat', 'pig', 'human'), 4)), 
+  "age" = sample(c(1:100), 12)
+)
 
 
 ## -----------------------------------------------------------------------------
@@ -455,7 +479,7 @@ df_list <- splt(df, 5, method = 'n_dist', randomize = TRUE)
 df_list %>% kable(align = 'c')
 
 
-## ----echo=FALSE---------------------------------------------------------------
+## ----echo=FALSE, eval=requireNamespace("ggplot2")-----------------------------
 
 # 
 # Examples to show difference between methods
@@ -533,7 +557,7 @@ v57n6_plot +
 
 
 
-## ----echo=FALSE---------------------------------------------------------------
+## ----echo=FALSE, eval=requireNamespace("ggplot2")-----------------------------
 
 
 
@@ -606,7 +630,7 @@ v117n11_plot +
   
 
 
-## ----echo=FALSE---------------------------------------------------------------
+## ----echo=FALSE, eval=requireNamespace("ggplot2")-----------------------------
 
 
 vec <- c(1:100)
@@ -649,7 +673,7 @@ greedy_plot +
 
 
 
-## ----echo=FALSE---------------------------------------------------------------
+## ----echo=FALSE, eval=requireNamespace("ggplot2")-----------------------------
 
 
 vec <- c(1:1000)
@@ -693,7 +717,7 @@ staircase_plot +
 
 
 
-## ----echo=FALSE---------------------------------------------------------------
+## ----echo=FALSE, eval=requireNamespace("ggplot2")-----------------------------
 
 staircase_data <- staircase_data %>%
   group_by(step_size) %>%
@@ -712,7 +736,7 @@ staircase_cumulative_plot +
         axis.text.x = element_text(size=7))
 
 
-## ----echo=FALSE---------------------------------------------------------------
+## ----echo=FALSE, eval=requireNamespace("ggplot2")-----------------------------
 
 
 vec <- c(1:1000)
@@ -755,7 +779,7 @@ primes_plot +
 
 
 
-## ----echo=FALSE---------------------------------------------------------------
+## ----echo=FALSE, eval=requireNamespace("ggplot2")-----------------------------
 
 primes_data <- primes_data %>%
   group_by(start_at) %>%
